CyberpayResult class

Indicates the result expected after payment is initiated

Constructors

CyberpayResult({required bool isPaymentSuccessFul, String? paymentReference, String? errorMessage})

Properties

errorMessage ↔ String?
The error message returned when a payment fails. This returns null when payment is successful
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
isPaymentSuccessFul ↔ bool
This returns true if the payment is successful, and false if payment fails
getter/setter pair
paymentReference ↔ String?
The payment reference
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited